@@ -1,39 +1,43 @@
 package IO::Interactive;
 
-use version; $VERSION = qv('0.0.1');
-
-use warnings;
 use strict;
-use Carp;
-use Scalar::Util qw( openhandle );
+use warnings;
+
+$IO::Interactive::VERSION = '1.021_02';
 
 sub is_interactive {
-    my ($out_handle) = (@_, \*STDOUT);    # Default to STDOUT
+    my ($out_handle) = (@_, select);    # Default to default output handle
 
     # Not interactive if output is not to terminal...
     return 0 if not -t $out_handle;
 
     # If *ARGV is opened, we're interactive if...
-    if (openhandle *ARGV) {
+    if ( tied(*ARGV) or defined(fileno(ARGV)) ) { # this is what 'Scalar::Util::openhandle *ARGV' boils down to
+
         # ...it's currently opened to the magic '-' file
         return -t *STDIN if defined $ARGV && $ARGV eq '-';
 
         # ...it's at end-of-file and the next file is the magic '-' file
         return @ARGV>0 && $ARGV[0] eq '-' && -t *STDIN if eof *ARGV;
 
-        # ...it's directly attached to the terminal 
+        # ...it's directly attached to the terminal
         return -t *ARGV;
     }
 
-    # If *ARGV isn't opened, it will be interactive if *STDIN is attached 
-    # to a terminal and either there are no files specified on the command line
-    # or if there are files and the first is the magic '-' file
+    # If *ARGV isn't opened, it will be interactive if *STDIN is attached
+    # to a terminal.
     else {
-        return -t *STDIN && (@ARGV==0 || $ARGV[0] eq '-');
+        return -t *STDIN;
     }
 }
 
-open my $dev_null, '>', \do{my $dev_null};
+local (*DEV_NULL, *DEV_NULL2);
+my $dev_null;
+BEGIN {
+    pipe *DEV_NULL, *DEV_NULL2
+        or die "Internal error: can't create null filehandle";
+    $dev_null = \*DEV_NULL;
+}
 
 sub interactive {
     my ($out_handle) = (@_, \*STDOUT);      # Default to STDOUT
@@ -56,7 +60,7 @@ sub busy (&) {
     # Non-interactive busy-ness is easy...just do it
     if (!is_interactive()) {
         $block_ref->();
-        open my $fh, '<', \"";
+        open my $fh, '<', \ "";
         return $fh;
     }
 
@@ -94,7 +98,7 @@ sub busy (&) {
 
     # Temporarily close the input...
     local *ARGV;
-    open *ARGV, '<', \"";
+    open *ARGV, '<', \ "";
 
     # Do the job...
     $block_ref->();
@@ -107,8 +111,6 @@ sub busy (&) {
     return $read;
 }
 
-use Carp;
-
 sub import {
     my ($package) = shift;
     my $caller = caller;
@@ -117,25 +119,26 @@ sub import {
     for my $request ( @_ ) {
         no strict 'refs';
         my $impl = *{$package.'::'.$request}{CODE};
-        croak "Unknown subroutine ($request()) requested"
-            if !$impl || $request =~ m/\A _/xms;
+        if(!$impl || $request =~ m/\A _/xms) {
+            require Carp;
+            Carp::croak("Unknown subroutine ($request()) requested");
+        }
         *{$caller.'::'.$request} = $impl;
     }
 }
 
-
 1; # Magic true value required at end of module
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 IO::Interactive - Utilities for interactive I/O
 
-
 =head1 VERSION
 
-This document describes IO::Interactive version 0.0.1
-
+This document describes IO::Interactive version 1.02
 
 =head1 SYNOPSIS
 
@@ -164,16 +167,17 @@ develop interactive applications...
 
 =item C<is_interactive()>
 
-This subroutine returns true if C<*ARGV> and C<*STDOUT> are connected to 
-the terminal. The test is considerably more sophisticated than:
+This subroutine returns true if C<*ARGV> and the currently selected
+filehandle (usually C<*STDOUT>) are connected to the terminal. The
+test is considerably more sophisticated than:
 
     -t *ARGV && -t *STDOUT
 
 as it takes into account the magic behaviour of C<*ARGV>.
 
 You can also pass C<is_interactive> a writable filehandle, in which case it
-requires that filehandle be connected to a terminal (instead of C<*STDOUT>).
-The usual suspect here is C<*STDERR>:
+requires that filehandle be connected to a terminal (instead of the
+currently selected).  The usual suspect here is C<*STDERR>:
 
     if ( is_interactive(*STDERR) ) {
         carp $warning;
@@ -193,12 +197,11 @@ application is interactive:
     my $value = <>;
 
 You can also pass C<interactive> a writable filehandle, in which case it
-writes to that filehandle if it is connected to a terminal (instead of 
-writinbg to C<*STDOUT>). Once again, the usual suspect is C<*STDERR>:
+writes to that filehandle if it is connected to a terminal (instead of
+writing to C<*STDOUT>). Once again, the usual suspect is C<*STDERR>:
 
     print {interactive(*STDERR)} $warning;
 
-
 =item C<busy {...}>
 
 This subroutine takes a block as its single argument and executes that block.
@@ -228,7 +231,6 @@ You asked for something else. Maybe you misspelled the subroutine you wanted.
 
 IO::Interactive requires no configuration files or environment variables.
 
-
 =head1 DEPENDENCIES
 
 This module requires the C<openhandle()> subroutine from the
@@ -239,20 +241,26 @@ Scalar::Util module.
 
 None reported.
 
-
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
-Please report any bugs or feature requests to
-C<bug-io-interactive@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
+Please report any bugs or feature requests to Github
+L<https://github.com/briandfoy/io-interactive/issues>.
 
+=head1 SOURCE AVAILABILITY
+
+This code is in GitHub:
+
+	https://github.com/briandfoy/io-interactive
 
 =head1 AUTHOR
 
 Damian Conway  C<< <DCONWAY@cpan.org> >>
 
+Currently maintained by brian d foy C<< <bdfoy@cpan.org> >>.
+
+1.01 patch DMUEY C<< dmuey@cpan.org >>
 
 =head1 LICENCE AND COPYRIGHT
 
@@ -284,3 +292,5 @@ RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
 FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
 SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGES.
+
+=cut
